﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.ComponentModel;
using HeuristicLab.MainForm;

namespace HeuristicLab.Problems.Instances.QAPGenerator.Views {
  [View("Tai-b QAP Instance Generator Descriptor View")]
  [Content(typeof(TaibQAPInstanceGeneratorDescriptor), IsDefaultView = true)]
  public partial class TaibQAPInstanceGeneratorDescriptorView : QAPInstanceGeneratorDescriptorView {

    public new TaibQAPInstanceGeneratorDescriptor Content {
      get { return (TaibQAPInstanceGeneratorDescriptor)base.Content; }
      set { base.Content = value; }
    }

    public TaibQAPInstanceGeneratorDescriptorView() {
      InitializeComponent();
    }

    #region Event Handlers (Content)
    protected override void ContentOnPropertyChanged(object sender, PropertyChangedEventArgs eventArgs) {
      base.ContentOnPropertyChanged(sender, eventArgs);
      SuppressEvents = true;
      try {
        switch (eventArgs.PropertyName) {
          case "MaxClusterDistance":
            globalRadiusNumericUpDown.Value = Content.MaxClusterDistance;
            break;
          case "MaxClusterSize":
            clusterSizeNumericUpDown.Value = Content.MaxClusterSize;
            break;
          case "MaxClusterRadius":
            clusterRadiusNumericUpDown.Value = Content.MaxClusterRadius;
            break;
          case "MinFlowExponent":
            minFlowExponentNumericUpDown.Value = Content.MinFlowExponent;
            break;
          case "MaxFlowExponent":
            maxFlowExponentNumericUpDown.Value = Content.MaxFlowExponent;
            break;
        }
      } finally { SuppressEvents = false; }
    }
    #endregion

    protected override void OnContentChanged() {
      base.OnContentChanged();
      SuppressEvents = true;
      try {
        if (Content == null) {
          globalRadiusNumericUpDown.Value = 0;
          clusterSizeNumericUpDown.Value = 0;
          clusterRadiusNumericUpDown.Value = 0;
          minFlowExponentNumericUpDown.Value = 0;
          maxFlowExponentNumericUpDown.Value = 0;
        } else {
          globalRadiusNumericUpDown.Value = Content.MaxClusterDistance;
          clusterSizeNumericUpDown.Value = Content.MaxClusterSize;
          clusterRadiusNumericUpDown.Value = Content.MaxClusterRadius;
          minFlowExponentNumericUpDown.Value = Content.MinFlowExponent;
          maxFlowExponentNumericUpDown.Value = Content.MaxFlowExponent;
        }
      } finally { SuppressEvents = false; }
    }


    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      globalRadiusNumericUpDown.Enabled = !Locked && !ReadOnly && Content != null;
      clusterSizeNumericUpDown.Enabled = !Locked && !ReadOnly && Content != null;
      clusterRadiusNumericUpDown.Enabled = !Locked && !ReadOnly && Content != null;
      minFlowExponentNumericUpDown.Enabled = !Locked && !ReadOnly && Content != null;
      maxFlowExponentNumericUpDown.Enabled = !Locked && !ReadOnly && Content != null;
    }

    #region Event Handlers (child controls)
    protected virtual void globalRadiusNumericUpDown_ValueChanged(object sender, EventArgs e) {
      if (SuppressEvents) return;
      Content.MaxClusterDistance = (int)globalRadiusNumericUpDown.Value;
    }

    protected virtual void clusterSizeNumericUpDown_ValueChanged(object sender, EventArgs e) {
      if (SuppressEvents) return;
      Content.MaxClusterSize = (int)clusterSizeNumericUpDown.Value;
    }

    protected virtual void clusterRadiusNumericUpDown_ValueChanged(object sender, EventArgs e) {
      if (SuppressEvents) return;
      Content.MaxClusterRadius = (int)clusterRadiusNumericUpDown.Value;
    }

    protected virtual void minFlowExponentNumericUpDown_ValueChanged(object sender, EventArgs e) {
      if (SuppressEvents) return;
      Content.MinFlowExponent = (int)minFlowExponentNumericUpDown.Value;
    }

    protected virtual void maxFlowExponentNumericUpDown_ValueChanged(object sender, EventArgs e) {
      if (SuppressEvents) return;
      Content.MaxFlowExponent = (int)maxFlowExponentNumericUpDown.Value;
    }
    #endregion
  }
}
